@@ -15,7 +15,7 @@ class GPUWorker(BaseWorker):
         else:
             job = self.queue_list.pop_to(self.working_list)
         if not job:
-            return
+            raise Exception('cant get job exception')
 
 #        gpus = gpu.getGPUs()
 #        availability = gpu.getAvailability(gpus, maxLoad=self.config.gpu_load,
