@@ -46,6 +46,10 @@ class DICOMConfig(object):
 
 
 def payload(job, config):
+
+    if not isinstance(job, DICOMJob):
+        raise Exception('not DICOMJob')
+
     print('playload running...')
     # get job
     content = job.content
@@ -103,9 +107,8 @@ def payload(job, config):
     files = os.listdir(des)
     if not files:
         print('prediction...')
-        from DICOM.AlgorithmAPI import main_interface
-        main_interface.predictLungCancer(
-            dcm_dir=base, model_dir='DICOM/models/', tgt_dir=des, tmp_dir='/tmp/plc/', pci_id='1')
+        from DICOM.AlgorithmAPI_v2 import api
+        api.main(data_dir=base, work_dir=des)
         files = os.listdir(des)
         metadata = job.create_metadata()
         for file_name in files:
@@ -120,7 +123,8 @@ def payload(job, config):
             if file_name.endswith('txt'):
                 with open('{des}/{file_name}'.format(des=des, file_name=file_name), 'r') as f:
                     result = f.read()
-                    metadata.fetures['total'] = result
+                    metadata.features['total'] = result
+                    
         if not os.path.isfile('{des}/metadata.json'.format(des=des)):
             print('write metadata')
             with open('{des}/metadata.json'.format(des=des), 'w+') as f:
