@@ -44,10 +44,21 @@ class WSIConfig(object):
 
 
 def payload(job, config):
+
+    if not isinstance(job, WSIJob):
+        raise Exception('not DICOMJob')
+
     print('playload running...')
     # get job
     content = job.content
     # get api information
+    base = '{base}/{accession_id}/'.format(
+        base=config.res_base,
+        accession_id=content.accession_id
+    )
+    if not os.path.isdir(base):
+        print('create path')
+        os.mkdir(base)
     print('get resource info')
     response = requests.get(content.api + content.image)
 
@@ -107,7 +118,7 @@ def payload(job, config):
             if file_name.endswith('txt'):
                 with open('{des}/{file_name}'.format(des=des, file_name=file_name), 'r') as f:
                     result = f.read()
-                    metadata.fetures['total'] = result
+                    metadata.features['total'] = result
         if not os.path.isfile('{des}/metadata.json'.format(des=des)):
             print('write metadata')
             with open('{des}/metadata.json'.format(des=des), 'w+') as f:
